@@ -357,7 +357,7 @@ class APIThread(threading.Thread):
 
 
 class Server(object):
-    def __init__(self, host, port, in_memory=False, default_bucket=None):
+    def __init__(self, host, port, in_memory, default_bucket=None):
         self._storage = Storage(use_memory_fs=in_memory)
         if default_bucket:
             logging.debug(
@@ -392,6 +392,6 @@ class Server(object):
             self.stop()
 
 
-def create_server(host, port, in_memory, default_bucket=None):
+def create_server(host, port, in_memory=False, default_bucket=None):
     logger.info("Starting server at {}:{}".format(host, port))
     return Server(host, port, in_memory=in_memory, default_bucket=default_bucket)
